'use strict';

const { sanitize } = require('@strapi/utils');
const formatError = error => [
  { messages: [{ id: error.id, message: error.message, field: error.field }] },
];

module.exports = {
  index: async ctx => {
    // Get posted params
    // const params = JSON.parse(ctx.request.body); //if post raw object using Postman
    const params = ctx.request.body;

    // The identifier is required.
    if (!params.identifier) {
      return ctx.badRequest(
        null,
        formatError({
          id: 'Auth.form.error.email.provide',
          message: 'Please provide your username or your e-mail.',
        })
      );
    }

    // The password is required.
    if (!params.password) {
      return ctx.badRequest(
        null,
        formatError({
          id: 'Auth.form.error.password.provide',
          message: 'Please provide your password.',
        })
      );
    }

    // The new password is required.
    if (!params.newPassword) {
      return ctx.badRequest(
        null,
        formatError({
          id: 'Auth.form.error.password.provide',
          message: 'Please provide your new password.',
        })
      );
    }

    // The new password confirmation is required.
    if (!params.confirmPassword) {
      return ctx.badRequest(
        null,
        formatError({
          id: 'Auth.form.error.password.provide',
          message: 'Please provide your new password confirmation.',
        })
      );
    }

    if (
      params.newPassword &&
      params.confirmPassword &&
      params.newPassword !== params.confirmPassword
    ) {
      return ctx.badRequest(
        null,
        formatError({
          id: 'Auth.form.error.password.matching',
          message: 'New Passwords do not match.',
        })
      );
    } else if (
      params.newPassword &&
      params.confirmPassword &&
      params.newPassword === params.confirmPassword
    ) {

      // console.log(params);

      // Get User based on identifier
      const user = await strapi.db.query('plugin::users-permissions.user').findOne({where: { id: params.identifier }});

      // console.log(user);

      // Validate given password against user query result password
      const validPassword = await strapi.plugins[
        'users-permissions'
        ].services.user.validatePassword(params.password, user.password);

      if (!validPassword) {
        return ctx.badRequest(
          null,
          formatError({
            id: 'Auth.form.error.invalid',
            message: 'Identifier or password invalid.',
          })
        );
      } else {
        const bcrypt = require('bcryptjs');

        // Generate new hash password
        const password = await bcrypt.hash(params.newPassword, 10);

        // Update user password
        await strapi.db.query('plugin::users-permissions.user').update({
         where: { id: user.id },
         data: { resetPasswordToken: null, password }
        });

        // Return new jwt token
        // console.log(user.toJSON)
        ctx.send({
          jwt: strapi.plugins['users-permissions'].services.jwt.issue({
            id: user.id,
          }),
          user: await sanitize.contentAPI.output(user),
        });
      }
    }
  }
};
